==> nats.c_3.4.1.orig.tar.gz: nats.c-3.4.1/doc/html/search/typedefs_0.js <==
var searchData=
[
  ['jsaccountinfo_0',['jsAccountInfo',['../group__types_group.html#ga57cdc53b29a4fedb5a4140b6e64a4fab',1,'nats.h']]],
  ['jsaccountlimits_1',['jsAccountLimits',['../group__types_group.html#gaa889f706cce285adb9cea8aba0b76866',1,'nats.h']]],
  ['jsapistats_2',['jsAPIStats',['../group__types_group.html#gad057a0107367ce5727975f3daf63ff75',1,'nats.h']]],
  ['jsclusterinfo_3',['jsClusterInfo',['../group__types_group.html#gaaf92318ce94a1ae3547c9a7af5a3f4f6',1,'nats.h']]],
  ['jsconsumerconfig_4',['jsConsumerConfig',['../group__types_group.html#ga0483b2197c0ddd9082b48c2dd3fe7cee',1,'nats.h']]],
  ['jsconsumerinfo_5',['jsConsumerInfo',['../group__types_group.html#ga2f21bb79884e56a5613d7fe76b11b1e5',1,'nats.h']]],
  ['jsconsumerinfolist_6',['jsConsumerInfoList',['../group__types_group.html#gadad3bf72baae970662248d82d9b05d0a',1,'nats.h']]],
  ['jsconsumernameslist_7',['jsConsumerNamesList',['../group__types_group.html#gad00ab4381eec504ada3272aa9ff8adb2',1,'nats.h']]],
  ['jsconsumersequencemismatch_8',['jsConsumerSequenceMismatch',['../group__types_group.html#gace471cd2cef1df797b2a1c6b485049bd',1,'nats.h']]],
  ['jsctx_9',['jsCtx',['../group__types_group.html#gaaf12cdd24c6cc23a57c20466c92ff8c1',1,'nats.h']]],
  ['jsdirectgetmsgoptions_10',['jsDirectGetMsgOptions',['../group__types_group.html#ga85123afa00d522a249a5b2a8abd7e063',1,'nats.h']]],
  ['jsexternalstream_11',['jsExternalStream',['../group__types_group.html#gaef6601477f6456bebc229f7f38982a6c',1,'nats.h']]],
  ['jsfetchrequest_12',['jsFetchRequest',['../group__types_group.html#gaf11e6664c1f335a5287af71c703935fa',1,'nats.h']]],
  ['jsloststreamdata_13',['jsLostStreamData',['../group__types_group.html#gaf80828510450faf84bbf456e94f5b784',1,'nats.h']]],
  ['jsmsgmetadata_14',['jsMsgMetaData',['../group__types_group.html#gace9595b1a5ce3f7a13670367fd293b4a',1,'nats.h']]],
  ['jsoptions_15',['jsOptions',['../group__types_group.html#ga0e3a3b7cf89e7dfa955f0f8f3f1eb6e5',1,'nats.h']]],
  ['jspeerinfo_16',['jsPeerInfo',['../group__types_group.html#ga1e938dab794089f9329d7b7ece8f3e9b',1,'nats.h']]],
  ['jsplacement_17',['jsPlacement',['../group__types_group.html#ga49d1138fac9da8b85d00a367081e91c9',1,'nats.h']]],
  ['jspuback_18',['jsPubAck',['../group__types_group.html#gaf1d5e436c5d41c5b9b96d84e3d2bc86f',1,'nats.h']]],
  ['jspubackerr_19',['jsPubAckErr',['../group__types_group.html#gadb7c287bc86b92765fbe45a066b96f40',1,'nats.h']]],
  ['jspubackerrhandler_20',['jsPubAckErrHandler',['../group__callbacks_group.html#ga954768cc1d3388bb6ab723e777647992',1,'nats.h']]],
  ['jspubackhandler_21',['jsPubAckHandler',['../group__callbacks_group.html#ga4f66e065bd918f02510d4c53d8a5b729',1,'nats.h']]],
  ['jspuboptions_22',['jsPubOptions',['../group__types_group.html#ga7bbea3575d35dcdbfc9b766b04269eb7',1,'nats.h']]],
  ['jsrepublish_23',['jsRePublish',['../group__types_group.html#gab991313d33ce270a882e4d0756c138f6',1,'nats.h']]],
  ['jssequenceinfo_24',['jsSequenceInfo',['../group__types_group.html#ga27e1a5d5b513f9eb7d61a17db71f8003',1,'nats.h']]],
  ['jssequencepair_25',['jsSequencePair',['../group__types_group.html#ga39011d30b295759b7f6ca0a7539dff8f',1,'nats.h']]],
  ['jsstreamconfig_26',['jsStreamConfig',['../group__types_group.html#ga26fd6a73df327ca3c271e46ddefc8acf',1,'nats.h']]],
  ['jsstreaminfo_27',['jsStreamInfo',['../group__types_group.html#ga2629c9454996edf7914be36a9e44921b',1,'nats.h']]],
  ['jsstreaminfolist_28',['jsStreamInfoList',['../group__types_group.html#ga1e54c2a1bc94834d1670875fc151f565',1,'nats.h']]],
  ['jsstreamnameslist_29',['jsStreamNamesList',['../group__types_group.html#gaf4d31a4dc83b2805422beafb1f8fa000',1,'nats.h']]],
  ['jsstreamsource_30',['jsStreamSource',['../group__types_group.html#gab4c43c87d81917aab748a50eee028449',1,'nats.h']]],
  ['jsstreamsourceinfo_31',['jsStreamSourceInfo',['../group__types_group.html#gab2f33f57188a550f2f747d4f27bc24bd',1,'nats.h']]],
  ['jsstreamstate_32',['jsStreamState',['../group__types_group.html#ga2bfd6de6ffc84d767482b3dd57cb9271',1,'nats.h']]],
  ['jsstreamstatesubject_33',['jsStreamStateSubject',['../group__types_group.html#ga55dce2fa9ecd215716cc9ceece7dfefa',1,'nats.h']]],
  ['jsstreamstatesubjects_34',['jsStreamStateSubjects',['../group__types_group.html#gae8b57d9c40364f97a705f3e61a1156b0',1,'nats.h']]],
  ['jssuboptions_35',['jsSubOptions',['../group__types_group.html#gaccfaac2079656ffd40d003e4de5d2280',1,'nats.h']]],
  ['jstier_36',['jsTier',['../group__types_group.html#ga1d48d3eb36b50c9ab6d8477dccf247d8',1,'nats.h']]]
];

==> nats.c_3.5.0.orig.tar.gz: nats.c-3.5.0/doc/html/search/typedefs_0.js <==
var searchData=
[
  ['jsaccountinfo_0',['jsAccountInfo',['../group__types_group.html#ga57cdc53b29a4fedb5a4140b6e64a4fab',1,'nats.h']]],
  ['jsaccountlimits_1',['jsAccountLimits',['../group__types_group.html#gaa889f706cce285adb9cea8aba0b76866',1,'nats.h']]],
  ['jsapistats_2',['jsAPIStats',['../group__types_group.html#gad057a0107367ce5727975f3daf63ff75',1,'nats.h']]],
  ['jsclusterinfo_3',['jsClusterInfo',['../group__types_group.html#gaaf92318ce94a1ae3547c9a7af5a3f4f6',1,'nats.h']]],
  ['jsconsumerconfig_4',['jsConsumerConfig',['../group__types_group.html#ga0483b2197c0ddd9082b48c2dd3fe7cee',1,'nats.h']]],
  ['jsconsumerinfo_5',['jsConsumerInfo',['../group__types_group.html#ga2f21bb79884e56a5613d7fe76b11b1e5',1,'nats.h']]],
  ['jsconsumerinfolist_6',['jsConsumerInfoList',['../group__types_group.html#gadad3bf72baae970662248d82d9b05d0a',1,'nats.h']]],
  ['jsconsumernameslist_7',['jsConsumerNamesList',['../group__types_group.html#gad00ab4381eec504ada3272aa9ff8adb2',1,'nats.h']]],
  ['jsconsumersequencemismatch_8',['jsConsumerSequenceMismatch',['../group__types_group.html#gace471cd2cef1df797b2a1c6b485049bd',1,'nats.h']]],
  ['jsctx_9',['jsCtx',['../group__types_group.html#gaaf12cdd24c6cc23a57c20466c92ff8c1',1,'nats.h']]],
  ['jsdirectgetmsgoptions_10',['jsDirectGetMsgOptions',['../group__types_group.html#ga85123afa00d522a249a5b2a8abd7e063',1,'nats.h']]],
  ['jsexternalstream_11',['jsExternalStream',['../group__types_group.html#gaef6601477f6456bebc229f7f38982a6c',1,'nats.h']]],
  ['jsfetchrequest_12',['jsFetchRequest',['../group__types_group.html#gaf11e6664c1f335a5287af71c703935fa',1,'nats.h']]],
  ['jsloststreamdata_13',['jsLostStreamData',['../group__types_group.html#gaf80828510450faf84bbf456e94f5b784',1,'nats.h']]],
  ['jsmsgmetadata_14',['jsMsgMetaData',['../group__types_group.html#gace9595b1a5ce3f7a13670367fd293b4a',1,'nats.h']]],
  ['jsoptions_15',['jsOptions',['../group__types_group.html#ga0e3a3b7cf89e7dfa955f0f8f3f1eb6e5',1,'nats.h']]],
  ['jspeerinfo_16',['jsPeerInfo',['../group__types_group.html#ga1e938dab794089f9329d7b7ece8f3e9b',1,'nats.h']]],
  ['jsplacement_17',['jsPlacement',['../group__types_group.html#ga49d1138fac9da8b85d00a367081e91c9',1,'nats.h']]],
  ['jspuback_18',['jsPubAck',['../group__types_group.html#gaf1d5e436c5d41c5b9b96d84e3d2bc86f',1,'nats.h']]],
  ['jspubackerr_19',['jsPubAckErr',['../group__types_group.html#gadb7c287bc86b92765fbe45a066b96f40',1,'nats.h']]],
  ['jspubackerrhandler_20',['jsPubAckErrHandler',['../group__callbacks_group.html#ga954768cc1d3388bb6ab723e777647992',1,'nats.h']]],
  ['jspubackhandler_21',['jsPubAckHandler',['../group__callbacks_group.html#ga4f66e065bd918f02510d4c53d8a5b729',1,'nats.h']]],
  ['jspuboptions_22',['jsPubOptions',['../group__types_group.html#ga7bbea3575d35dcdbfc9b766b04269eb7',1,'nats.h']]],
  ['jsrepublish_23',['jsRePublish',['../group__types_group.html#gab991313d33ce270a882e4d0756c138f6',1,'nats.h']]],
  ['jssequenceinfo_24',['jsSequenceInfo',['../group__types_group.html#ga27e1a5d5b513f9eb7d61a17db71f8003',1,'nats.h']]],
  ['jssequencepair_25',['jsSequencePair',['../group__types_group.html#ga39011d30b295759b7f6ca0a7539dff8f',1,'nats.h']]],
  ['jsstreamalternate_26',['jsStreamAlternate',['../group__types_group.html#ga22c26dd5dd31df7982130ef203ad3490',1,'nats.h']]],
  ['jsstreamconfig_27',['jsStreamConfig',['../group__types_group.html#ga26fd6a73df327ca3c271e46ddefc8acf',1,'nats.h']]],
  ['jsstreaminfo_28',['jsStreamInfo',['../group__types_group.html#ga2629c9454996edf7914be36a9e44921b',1,'nats.h']]],
  ['jsstreaminfolist_29',['jsStreamInfoList',['../group__types_group.html#ga1e54c2a1bc94834d1670875fc151f565',1,'nats.h']]],
  ['jsstreamnameslist_30',['jsStreamNamesList',['../group__types_group.html#gaf4d31a4dc83b2805422beafb1f8fa000',1,'nats.h']]],
  ['jsstreamsource_31',['jsStreamSource',['../group__types_group.html#gab4c43c87d81917aab748a50eee028449',1,'nats.h']]],
  ['jsstreamsourceinfo_32',['jsStreamSourceInfo',['../group__types_group.html#gab2f33f57188a550f2f747d4f27bc24bd',1,'nats.h']]],
  ['jsstreamstate_33',['jsStreamState',['../group__types_group.html#ga2bfd6de6ffc84d767482b3dd57cb9271',1,'nats.h']]],
  ['jsstreamstatesubject_34',['jsStreamStateSubject',['../group__types_group.html#ga55dce2fa9ecd215716cc9ceece7dfefa',1,'nats.h']]],
  ['jsstreamstatesubjects_35',['jsStreamStateSubjects',['../group__types_group.html#gae8b57d9c40364f97a705f3e61a1156b0',1,'nats.h']]],
  ['jssuboptions_36',['jsSubOptions',['../group__types_group.html#gaccfaac2079656ffd40d003e4de5d2280',1,'nats.h']]],
  ['jstier_37',['jsTier',['../group__types_group.html#ga1d48d3eb36b50c9ab6d8477dccf247d8',1,'nats.h']]]
];
